==> haskell-hasql-1.5-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql
version:              1.5
visibility:           public
id:                   hasql-1.5-FBVwGHFxgAMKc0Y4UAL5HZ
key:                  hasql-1.5-FBVwGHFxgAMKc0Y4UAL5HZ
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql
synopsis:             An efficient PostgreSQL driver with a flexible mapping API
description:
    Root of the \"hasql\" ecosystem.
    For details and tutorials see
    <https://github.com/nikita-volkov/hasql the readme>.

    The API comes free from all kinds of exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.

category:             Hasql, Database, PostgreSQL
abi:                  5f27d21447afdfd9d273496539c86787
exposed:              True
exposed-modules:
    Hasql.Connection Hasql.Decoders Hasql.Encoders Hasql.Session
    Hasql.Statement

hidden-modules:
    Hasql.Private.Prelude Hasql.Private.Errors Hasql.Private.PTI
    Hasql.Private.IO Hasql.Private.Session Hasql.Private.Connection
    Hasql.Private.PreparedStatementRegistry Hasql.Private.Settings
    Hasql.Private.Commands Hasql.Private.Decoders
    Hasql.Private.Decoders.Array Hasql.Private.Decoders.Composite
    Hasql.Private.Decoders.Value Hasql.Private.Decoders.Row
    Hasql.Private.Decoders.Result Hasql.Private.Decoders.Results
    Hasql.Private.Encoders Hasql.Private.Encoders.Array
    Hasql.Private.Encoders.Value Hasql.Private.Encoders.Params

import-dirs:          /usr/lib/ghc-9.0.2/site-local/hasql-1.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hasql-1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql
hs-libraries:         HShasql-1.5-FBVwGHFxgAMKc0Y4UAL5HZ
depends:
    attoparsec-0.14.4-JmvG4Wvx4EM5mKBIEGEaPX base-4.15.1.0
    bytestring-0.10.12.1
    bytestring-strict-builder-0.4.5.5-LGmojLjIRlMJStWboletyo
    contravariant-1.5.5-FtJyCLyWfutGN2UWoJs8qd
    dlist-1.0-9urp3Veuit69E8zxpJRI9E
    hashable-1.4.0.2-A7cEvE0oiq92I0kqqbT0NC
    hashtables-1.2.4.2-DDwlkgdpLSx5v7NlECMp0f mtl-2.2.2
    postgresql-binary-0.12.4.1-B9QISc5fHyFL0vPllPeGJ9
    postgresql-libpq-0.9.4.3-IkP6G59sk5XEvvBwPSqWYy
    profunctors-5.6.2-EvzKwMTHiQKCqir8d4JifK text-1.2.5.0
    text-builder-0.6.6.5-1CBCH00FBnXDgMbNnAdqqm transformers-0.5.6.2
    vector-0.12.3.1-35O4ef8MZDE9Y9qFX9F3Ug

haddock-interfaces:   /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html:         /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-1.5-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql
version:              1.5
visibility:           public
id:                   hasql-1.5-646ouBFKQ9u87DyUVclCNE
key:                  hasql-1.5-646ouBFKQ9u87DyUVclCNE
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql
synopsis:             An efficient PostgreSQL driver with a flexible mapping API
description:
    Root of the \"hasql\" ecosystem.
    For details and tutorials see
    <https://github.com/nikita-volkov/hasql the readme>.

    The API comes free from all kinds of exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.

category:             Hasql, Database, PostgreSQL
abi:                  231f338bcd54581c69c384bea8c8e19e
exposed:              True
exposed-modules:
    Hasql.Connection Hasql.Decoders Hasql.Encoders Hasql.Session
    Hasql.Statement

hidden-modules:
    Hasql.Private.Prelude Hasql.Private.Errors Hasql.Private.PTI
    Hasql.Private.IO Hasql.Private.Session Hasql.Private.Connection
    Hasql.Private.PreparedStatementRegistry Hasql.Private.Settings
    Hasql.Private.Commands Hasql.Private.Decoders
    Hasql.Private.Decoders.Array Hasql.Private.Decoders.Composite
    Hasql.Private.Decoders.Value Hasql.Private.Decoders.Row
    Hasql.Private.Decoders.Result Hasql.Private.Decoders.Results
    Hasql.Private.Encoders Hasql.Private.Encoders.Array
    Hasql.Private.Encoders.Value Hasql.Private.Encoders.Params

import-dirs:          /usr/lib/ghc-9.0.2/site-local/hasql-1.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hasql-1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql
hs-libraries:         HShasql-1.5-646ouBFKQ9u87DyUVclCNE
depends:
    attoparsec-0.14.4-C8JScaBf7EBAyHQottuuQN base-4.15.1.0
    bytestring-0.10.12.1
    bytestring-strict-builder-0.4.5.5-Ipt36Sgr8bsBDvUy7fKm2R
    contravariant-1.5.5-FtJyCLyWfutGN2UWoJs8qd
    dlist-1.0-ImNlUre2rHgIkuGbqNQCOO
    hashable-1.4.0.2-J44BDnT4N4jIfsjZsKg5ZQ
    hashtables-1.2.4.2-7X8yZlt7Jc2CBlbFFN7oIe mtl-2.2.2
    postgresql-binary-0.12.4.1-CcNpFdmm8EX8UUrZrBSiUf
    postgresql-libpq-0.9.4.3-IkP6G59sk5XEvvBwPSqWYy
    profunctors-5.6.2-FRAyuphOIkq5v7FzkaI8Ys text-1.2.5.0
    text-builder-0.6.6.5-2Z8zEz2oVQWAbVivza1Qxd transformers-0.5.6.2
    vector-0.12.3.1-J4wWiZyTUBGFVf3h0yMQvX

haddock-interfaces:   /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html:         /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
